==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Voltooid</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>As-beperking...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>Stel een as-beperking in tussen twee objecten</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Zelf-test...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Voert een zelf-test uit, om te controleren of de toepassing correct werkt</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Dr&amp;awing</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>S&amp;ketch</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Realistische Weergave</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Schetsen</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Schets gebaseerd</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Primitives</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametrisch</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Object uiterlijk</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Lijn Gereedschap</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Voltooid</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>As-beperking...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>Stel een as-beperking in tussen twee objecten</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Zelf-test...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Voert een zelf-test uit, om te controleren of de toepassing correct werkt</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Dr&amp;awing</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>S&amp;chets</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Realistische Weergave</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Schetsen</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Schets gebaseerd</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Basisvormen</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametrisch</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Object uiterlijk</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Lijn Gereedschap</translation>
    </message>
  </context>
</TS>
